/*
** Module   : MenuChuiImpl.java
** Abstract : CHUI client implementation of Menu.
**
** Copyright (c) 2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -----------------------------Description-----------------------------
** 001 VIG 20150116 Created initial version.
*/
package com.goldencode.p2j.ui.client.chui;

import java.util.List;

import com.goldencode.p2j.ui.*;
import com.goldencode.p2j.ui.client.*;
import com.goldencode.p2j.ui.client.chui.driver.ChuiOutputManager;
import com.goldencode.p2j.ui.client.event.KeyInput;
import com.goldencode.p2j.ui.client.widget.*;

/**
 * <code>Menu</code> CHUI client implementation class. 
 */
public class MenuItemChuiImpl
extends MenuItem<ChuiOutputManager>
{
   /**
    * Special constructor used to restore component using given configuration.
    * 
    * @param   id
    *          The widget's ID.
    * @param   cfg
    *          Configuration data.
    */
   public MenuItemChuiImpl(WidgetId id, WidgetConfig cfg)
   {
      super(id, (MenuItemConfig) cfg);
   }

   /**
    * Draw the peer container. The methods calls the draw() method for
    * ScrollPane instance for the peer container. In addition the required
    * clipping rectangle is calculated for ChildFrame containers because they
    * must be rendered inside the parent container.
    * <p>
    * Drawing for the redirected terminal differs. Labels/headers are drawn
    * only once per page, instead of the usual once per menu.
    */
   @Override
   public void draw()
   {
      Color dColor = config().dcolor == null ? Color.NORMAL : config().dcolor;
      AbstractContainer<ChuiOutputManager> parent = (AbstractContainer<ChuiOutputManager>) parent();
      List<Widget<ChuiOutputManager>> widgets = parent.getWidgetsList();
      int idx = widgets.indexOf(this);
      if (idx == -1) 
      {
         throw new IllegalStateException("MENU-ITEM is not contained in its parents widgets list");
      }
      Point p = parent.location();
      p = new Point(p.x + 1, p.y + 1 + idx);
      screen().at(p).append(this.config().title, dColor);
   }

   /**
    * Get widget dimension.
    * 
    * @return  widget dimension.
    */
   @Override
   public Dimension dimension()
   {
      return new Dimension(this.config().title.length(), 1);
   }

   /**
    * Get widget height.
    * 
    * @return  widget height.
    */
   @Override
   public double height()
   {
      return 1;
   }

   /**
    * Get widget minimum size.
    * 
    * @return  widget minimum size.
    */
   @Override
   public Dimension minimumSize()
   {
      // TODO Auto-generated method stub
      return null;
   }

   /**
    * Get widget width.
    * 
    * @return  widget width.
    */
   @Override
   public double width()
   {
      return config().title.length();
   }

   /**
    * Process key event.
    * 
    * @param   event
    *          Key event to process.
    */
   @Override
   public void processKeyEvent(KeyInput event)
   {
      // TODO Auto-generated method stub
      super.processKeyEvent(event);
   }

   /**
    * Process key listeners.
    * 
    * @param    event
    *           Keyboard event.
    */
   @Override
   public void processKeyListeners(KeyInput event)
   {
      // TODO Auto-generated method stub
      super.processKeyListeners(event);
   }

   /**
    * Check if widget needs in cursor to be on when having the input focus.  By default this
    * method always returns <code>true</code> so it needs to be overwritten if other return value
    * is required for particular widget implementation class.
    * 
    * @return  <code>true</code> as the default value.
    */
   @Override
   public boolean forceCursorOnFocus()
   {
      return false;
   }

}
